/* Copyright 2020 Purdea Andrei
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include QMK_KEYBOARD_H

// Defines names for use in layer keycodes and the keymap
enum layer_names {
    _BASE,
    _FN,
    _FN2
};

// Defines the keycodes used by our macros in process_record_user
enum custom_keycodes {
    Q_SFT = SAFE_RANGE,
    Q_ADM,
    Q_STD,
    Q_HOM,
    Q_ROL,
    Q_SYS,
    Q_DIS
};

enum {
  TD_DOT = 0
};

qk_tap_dance_action_t tap_dance_actions[] = {
  [TD_DOT] = ACTION_TAP_DANCE_DOUBLE(KC_DOT, KC_COMM)
};

const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
    /* Base */
    [_BASE] = LAYOUT_ansi_hhkb_split_shift_regular_backspace(
        KC_ESC, KC_1, KC_2, KC_3, KC_4, KC_5, KC_6, KC_7, KC_8, KC_9, KC_0, KC_MINS, KC_EQL, KC_BSPC,            KC_INS,  KC_HOME,  KC_PGUP,
        KC_TAB,    KC_Q, KC_W, KC_E, KC_R, KC_T, KC_Y, KC_U, KC_I, KC_O, KC_P, KC_LBRC, KC_RBRC, KC_BSLS,        KC_DEL,  KC_END,   KC_PGDN,
        KC_LCTRL,     KC_A, KC_S, KC_D, KC_F, KC_G, KC_H, KC_J, KC_K, KC_L, KC_SCLN, KC_QUOT, KC_ENT,            KC_VOLD, KC_MUTE,  KC_VOLU,
        KC_LSFT,         KC_Z, KC_X, KC_C, KC_V, KC_B, KC_N, KC_M, KC_COMM, KC_DOT, KC_SLSH, KC_RSFT, TG(_FN),   KC_F5,   KC_UP,    KC_F12,
        KC_LALT, MO(_FN2), KC_LGUI,                      KC_SPC,                  KC_RGUI, MO(_FN2), KC_RALT,    KC_LEFT, KC_DOWN,  KC_RIGHT
    ),
    [_FN] = LAYOUT_ansi_hhkb_split_shift_regular_backspace(
        _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,             KC_7,    KC_8,    KC_9,
        _______,     _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,         KC_4,    KC_5,    KC_6,
        _______,         _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,              KC_1,    KC_2,    KC_3,
        _______,             _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,          KC_0,    _______, TD(TD_DOT),
        _______, _______, _______,                             _______,                                       _______, _______, _______,          _______, _______, _______
    ),
    [_FN2] = LAYOUT_ansi_hhkb_split_shift_regular_backspace(
        KC_GRV, KC_F1, KC_F2, KC_F3, KC_F4, KC_F5, KC_F6, KC_F7, KC_F8,   KC_F9, KC_F10,    KC_F11, KC_F12, KC_DEL,            KC_7,      KC_8,     KC_9,
        Q_DIS,      KC_NO, Q_SYS, KC_NO, Q_ROL, KC_NO, KC_NO, KC_NO, KC_NO, KC_NO, KC_NO, HPT_DWLD, HPT_DWLI, HPT_TOG,         KC_4,      KC_5,     KC_6,
        _______,     Q_ADM, Q_STD, KC_F17, KC_NO, KC_NO, Q_HOM, KC_NO, KC_NO, KC_NO, KC_NO, KC_NO, _______,                    KC_1,      KC_2,     KC_3,
        Q_DIS,           KC_NO, KC_NO, KC_NO, KC_NO, KC_NO, KC_NO, KC_MUTE, KC_VOLD, KC_VOLU, KC_NO, _______, _______,         KC_0,      KC_PGUP,  TD(TD_DOT),
        _______, _______, _______,                             MO(_FN2),                           _______, _______, _______,  KC_HOME,   KC_PGDN,  KC_ENT
    )
};

void keyboard_pre_init_user(void) {
    setPinOutput(B4);  // initialize B4 for BLUE LED
    setPinOutput(B5);  // initialize B5 for RED  LED
}

bool process_record_user(uint16_t keycode, keyrecord_t *record) {
    switch (keycode) {
        case Q_ADM:
            if (record->event.pressed) {
                // when keycode ADM is pressed
                SEND_STRING("Proadrenomedullin N-20 Terminal Peptide");
            } else {
                // when keycode ADM is released
            }
            break;
        case Q_STD:
            if (record->event.pressed) {
                // when keycode STD is pressed
                SEND_STRING("Sulfotransferase Family 2A Member 1");
            } else {
                // when keycode QMKURL is released
            }
            break;
        case Q_HOM:
            if (record->event.pressed) {
                // when keycode HOM is pressed
                SEND_STRING("Heat Shock Protein Family A");
            } else {
                // when keycode HOM is released
            }
            break;
        case Q_ROL:
            if (record->event.pressed) {
                // when keycode ROL is pressed
                SEND_STRING("Retinol Binding Protein");
            } else {
                // when keycode ROL is released
            }
            break;
        case Q_SYS:
            if (record->event.pressed) {
                // when keycode SYS is pressed
                SEND_STRING("Seryl-TRNA Synthetase 2");
            } else {
                // when keycode SYS is released
            }
            break;
        case Q_DIS:
            if (record->event.pressed) {
                // when keycode DIS is pressed
		SEND_STRING(
	        SS_TAP(X_LSFT)
		    SS_DELAY(200)
		    SS_TAP(X_LSFT)
		    );
            } else {
                // when keycode DIS is released
            }
            break;


    }
    return true;
}

layer_state_t layer_state_set_user(layer_state_t state) {
   switch (get_highest_layer(state)) {
    case 0:
        writePinLow(B5);
	writePinLow(B4);
        break;
    case 1:
        writePinHigh(B5);
	writePinLow(B4);
        break;
    case 2:
        writePinLow(B5);
	writePinHigh(B4);
        break;
    default: //  for any other layers, or the default layer
        writePinLow(B5);
	writePinLow(B4);;
        break;
    }
  return state;
}

/*
void matrix_init_user(void) {

}

void matrix_scan_user(void) {

}

bool led_update_user(led_t led_state) {
    return true;
}
*/
